@@ -29,8 +29,8 @@
 #' @param mdr_filename The filename of the mdr (e.g. "mdr_example_data.csv").
 #' @param logfile_dir Is the absolute path to the directory where the logfile
 #'   will be stored. If not path is provided the tempdir() will be used.
-#' @param parallel A boolean. If TRUE (the default value), initializing
-#'   `future::plan("multiprocess")` before running the code.
+#' @param parallel A boolean. If TRUE, initializing a `future::plan()`
+#'   for running the code (default: FALSE).
 #' @param ncores A integer. The number of cores to use. Caution: you would
 #'   probably like to choose a low number when operating on large datasets.
 #'   Default: 2.
@@ -53,7 +53,7 @@ launch_app <- function(port = 3838,
                                                 package = "DQAstats"),
                        mdr_filename = "mdr_example_data.csv",
                        logfile_dir = tempdir(),
-                       parallel = TRUE,
+                       parallel = FALSE,
                        ncores = 2) {
 
   DIZtools::assign_to_R_env(key = "utils_path",
@@ -80,6 +80,7 @@ launch_app <- function(port = 3838,
 
   message(
     paste0(
+      "\nVersion DIZtools: ", utils::packageVersion("DIZtools"),
       "\nVersion DIZutils: ", utils::packageVersion("DIZutils"),
       "\nVersion DQAstats: ", utils::packageVersion("DQAstats"),
       "\nVersion DQAgui: ", utils::packageVersion("DQAgui"),
